@@ -82,7 +82,9 @@ binnings = {}
 
 binnings["Pi"] = {
     "P": p_binning("Pi"),
+    "Brunel_P": p_binning("Pi"),
     "ETA": eta_binning("Pi"),
+    "Brunel_ETA": eta_binning("Pi"),
     "nTracks": ntracks_binning("Pi"),
     "nTracks_Brunel": ntracks_binning("Pi"),
     "nSPDhits": nspdhits_binning("Pi"),
@@ -92,10 +94,22 @@ binnings["Pi"] = {
 
 binnings["K"] = {
     "P": p_binning("K"),
+    "Brunel_P": p_binning("K"),
     "ETA": eta_binning("K"),
+    "Brunel_ETA": eta_binning("K"),
     "nTracks": ntracks_binning("K"),
     "nTracks_Brunel": ntracks_binning("K"),
     "nSPDhits": nspdhits_binning("K"),
     "nSPDhits_Brunel": nspdhits_binning("K"),
     "TRCHI2NDOF": trchi2_binning("K"),
 }
+
+binnings["Mu"] = {
+    "P": p_binning("Mu"),
+    "ETA": eta_binning("Mu"),
+    "nTracks": ntracks_binning("Mu"),
+    "nTracks_Brunel": ntracks_binning("Mu"),
+    "nSPDhits": nspdhits_binning("Mu"),
+    "nSPDhits_Brunel": nspdhits_binning("Mu"),
+    "TRCHI2NDOF": trchi2_binning("Mu"),
+}
