@@ -44,14 +44,16 @@ from logzero import logger as log
 from . import pid_data, utils
 
 try:
-    from .version import version
+    from .version import version  # type: ignore
 except ImportError:
     version = "N/A"
 
 
 def decode_arguments(args):
     """Decode CLI arguments."""
-    parser = argparse.ArgumentParser(allow_abbrev=False)
+    parser = argparse.ArgumentParser(
+        allow_abbrev=False, formatter_class=argparse.ArgumentDefaultsHelpFormatter
+    )
     parser.add_argument(
         "-s",
         "--sample",
@@ -96,7 +98,7 @@ def decode_arguments(args):
     parser.add_argument(
         "-b",
         "--bin-var",
-        help="binning variable (-v can be used multiple times for multiple variables)",
+        help="binning variable (-b can be used multiple times for multiple variables)",
         action="append",
         dest="bin_vars",
         required=True,
@@ -231,6 +233,8 @@ def make_eff_hists(config: dict) -> None:
                 pickle.dump(eff_hists[f"eff_{cut}"], f)
                 pickle.dump(eff_hists[f"passing_{cut}"], f)
                 pickle.dump(eff_hists["total"], f)
+                pickle.dump(eff_hists[f"passing_sumw2_{cut}"], f)
+                pickle.dump(eff_hists["total_sumw2"], f)
 
             log.info(f"Efficiency histograms saved to '{eff_hist_path}'")
 
